@@ -2,8 +2,9 @@ from models import User
 import factory
 import random
 
-class UserFactory(factory.Factory):
+class UserFactory(factory.DjangoModelFactory):
     FACTORY_FOR = User
 
     remote_id = factory.Sequence(lambda n: n)
-    sex = random.choice([1,2])
\ No newline at end of file
+    sex = random.choice([1,2])
+    wall_comments = False
\ No newline at end of file
